============
Change Log
============

0.1
------------
*1 Feb 2012*

- Initial public release.

0.1.1
------------
*3 Feb 2012*

- Fixed `issue #1 <https://github.com/jessedhillon/pyramid_scss/issues/1>`_: @import could not resolve paths relative to ``asset_path``.

0.2
------------
*19 Feb 2012*

- Fixed `issue #3 <https://github.com/jessedhillon/pyramid_scss/issues/3>`_: caching implementation was incomplete/incorrect.
- Added ``static_path`` configuration for indicating location of static assets.

0.3
------------
*12 May 2013*

- Fixed `issue #4 <https://github.com/jessedhillon/pyramid_scss/issues/4>`_: exposed ASSETS_* and STATIC_* SCSS configuration settings.
- Various minor bugfixes, see commit history.

0.4
------------
*17 Apr 2014*

- Compatibility with Python 3 and pyScss 1.2.
